==> bolter_flutter-7.0.3.tar.gz: README.md <==
# Bolter: A Lightning-Fast State Management Solution for Flutter ⚡

Welcome to Bolter, an innovative, high-performance state management library for Flutter that will supercharge your app development process! This library is designed to provide a simple and efficient way to manage your app's state, making it easier than ever to build reactive, scalable, and maintainable applications.

## 🌟 Key Features

- 🚀 High-performance: **Bolter** is optimized for speed, ensuring your app runs smoothly even when dealing with large and complex state objects.
- 🔄 Reactive: Automatically update your UI components when the state changes, without any boilerplate code.
- 🔩 Flexible: Works seamlessly with various app architectures, allowing you to integrate it into your existing projects without hassle.
- 📚 Easy to learn: Clear, concise documentation and examples make it easy to get started and understand how Bolter works.

## 📦 Installation

To add Bolter to your Flutter project, simply add the following to your pubspec.yaml:

```yaml
dependencies:
  bolter: ^1.0.0
```
Then run flutter packages get to install the package.

## 🚀 Getting Started

Bolter provides a set of powerful tools to manage your app's state, including the BolterInterface, Presenter, and SyncBuilder. Let's take a quick tour of these core components and see how they work together to make your app development experience a breeze!

1. Bolter
Bolter is the central hub for state management in your app. It allows you to:

- Register state getters and listeners.
- Notify listeners of state changes.
- Manage state update lifecycle.

2. Presenter
The Presenter class is a powerful abstraction for managing state and logic in your app. It works seamlessly with the BolterInterface to provide a clean and organized way to manage stateful logic.

```dart
class CounterPresenter extends Presenter<CounterPresenter> {
  int _count = 0;

  int get count => _count;

  void increment() {
    perform(action: () {
      _count++;
    });
  }
}
```

3. BolterBuilder
BolterBuilder is a powerful widget that automatically updates your UI when the state changes. It works with both state getters and controllers, making it incredibly flexible and easy to use.

```dart
class CounterScreen extends StatelessWidget {

  @override
  Widget build(BuildContext context) {
    final presenter = context.presenter<CounterPresenter>();
    return Scaffold(
      appBar: AppBar(title: Text('Counter')),
      body: Center(
        child: BolterBuilder<int>(
          getter: _presenter.count,
          builder: (context, count) => Text('Count: $count'),
        ),
      ),
      floatingActionButton: FloatingActionButton(
        onPressed: _presenter.increment,
        child: Icon(Icons.add),
      ),
    );
  }
}
```
With these powerful tools at your disposal, you'll be able to build incredible apps in record time! 🚀

==> bolter_flutter-7.0.4.tar.gz: README.md <==
# Bolter: A Lightning-Fast State Management Solution for Flutter ⚡

Welcome to Bolter, an innovative, high-performance state management library for Flutter that will supercharge your app development process! This library is designed to provide a simple and efficient way to manage your app's state, making it easier than ever to build reactive, scalable, and maintainable applications.

## 🌟 Key Features

- 🚀 High-performance: **Bolter** is optimized for speed, ensuring your app runs smoothly even when dealing with large and complex state objects.
- 🔄 Reactive: Automatically update your UI components when the state changes, without any boilerplate code.
- 🔩 Flexible: Works seamlessly with various app architectures, allowing you to integrate it into your existing projects without hassle.
- 📚 Easy to learn: Clear, concise documentation and examples make it easy to get started and understand how Bolter works.

## 📦 Installation

To add Bolter to your Flutter project, simply add the following to your pubspec.yaml:

```yaml
dependencies:
  bolter: ^1.0.0
```
Then run flutter packages get to install the package.

## 🚀 Getting Started

Bolter provides a set of powerful tools to manage your app's state, including the BolterInterface, Presenter, and SyncBuilder. Let's take a quick tour of these core components and see how they work together to make your app development experience a breeze!

1. Bolter
Bolter is the central hub for state management in your app. It allows you to:

- Register state getters and listeners.
- Notify listeners of state changes.
- Manage state update lifecycle.

2. Presenter
The Presenter class is a powerful abstraction for managing state and logic in your app. It works seamlessly with the BolterInterface to provide a clean and organized way to manage stateful logic.

```dart
class CounterPresenter extends Presenter<CounterPresenter> {
  int _count = 0;

  int get count => _count;

  void increment() {
    perform(action: () {
      _count++;
    });
  }
}
```

3. BolterBuilder
BolterBuilder is a powerful widget that automatically updates your UI when the state changes. It works with both state getters and controllers, making it incredibly flexible and easy to use.

```dart
class CounterScreen extends StatelessWidget {
  const CounterScreen({super.key});

  @override
  Widget build(BuildContext context) {
    final presenter = context.presenter<CounterPresenter>();
    return Scaffold(
      appBar: AppBar(title: const Text('Counter')),
      body: Center(
        child: BolterBuilder(
          getter: () => presenter.count,
          builder: (context, count) => Text('Count: $count'),
        ),
      ),
      floatingActionButton: FloatingActionButton(
        onPressed: presenter.increment,
        child: const Icon(Icons.add),
      ),
    );
  }
}
```
With these powerful tools at your disposal, you'll be able to build incredible apps in record time! 🚀
